From: Vitaly Rodionov <vitalyr@opensource.cirrus.com>
To: Mark Brown <broonie@kernel.org>,
Krzysztof Kozlowski <krzk+dt@kernel.org>
Cc: Takashi Iwai <tiwai@suse.com>, Jaroslav Kysela <perex@perex.cz>,
David Rhodes <david.rhodes@cirrus.com>,
Richard Fitzgerald <rf@opensource.cirrus.com>,
Liam Girdwood <lgirdwood@gmail.com>,
Rob Herring <robh@kernel.org>, Conor Dooley <conor+dt@kernel.org>,
linux-sound@vger.kernel.org, linux-kernel@vger.kernel.org,
patches@opensource.cirrus.com, devicetree@vger.kernel.org,
Vitaly Rodionov <vitalyr@opensource.cirrus.com>
Subject: [PATCH v6 07/12] ASoC: cs530x: Rename bitfield to reflect common use for ADC and DAC
Date: Thu, 23 Oct 2025 10:03:15 +0100 [thread overview]
Message-ID: <20251023090327.58275-8-vitalyr@opensource.cirrus.com> (raw)
In-Reply-To: <20251023090327.58275-1-vitalyr@opensource.cirrus.com>
Signed-off-by: Vitaly Rodionov <vitalyr@opensource.cirrus.com>
---
sound/soc/codecs/cs530x.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/sound/soc/codecs/cs530x.c b/sound/soc/codecs/cs530x.c
index 4b0bf1c3b985..193d7af5cfd5 100644
--- a/sound/soc/codecs/cs530x.c
+++ b/sound/soc/codecs/cs530x.c
@@ -141,8 +141,8 @@ static int cs530x_put_volsw_vu(struct snd_kcontrol *kcontrol,
if (ret)
goto volsw_err;
- /* Write IN_VU bit for the volume change to take effect */
- regmap_write(regmap, CS530X_IN_VOL_CTRL5, CS530X_IN_VU);
+ /* Write INOUT_VU bit for the volume change to take effect */
+ regmap_write(regmap, CS530X_IN_VOL_CTRL5, CS530X_INOUT_VU);
volsw_err:
snd_soc_dapm_mutex_unlock(dapm);
--
2.43.0
next prev parent reply other threads:[~2025-10-23 9:03 UTC|newest]
Thread overview: 18+ messages / expand[flat|nested] mbox.gz Atom feed top
2025-10-23 9:03 [PATCH v6 00/12] Add support for Cirrus Logic CS530x DAC and CODEC variants Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 01/12] ASoC: cs530x: Update the copyright headers Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 02/12] ASoC: cs530x: Sort #include directives and tydy up whitespaces Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 03/12] ASoC: cs530x: Remove unused struct members and constants Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 04/12] ASoC: cs530x: Correct constant naming Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 05/12] ASoC: dt-bindings: sound: cirrus: cs530x: Add cs530x Vitaly Rodionov
2025-10-23 14:41 ` Rob Herring (Arm)
2025-10-23 18:15 ` Krzysztof Kozlowski
2025-10-23 20:57 ` Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 06/12] ASoC: cs530x: Add CODEC and DAC support Vitaly Rodionov
2025-10-23 9:03 ` Vitaly Rodionov [this message]
2025-10-23 9:03 ` [PATCH v6 08/12] ASoC: cs530x: Check the DEVID matches the devtype Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 09/12] ASoC: cs530x: Correct MCLK reference frequency values Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 10/12] ASoC: cs530x: Rename i2c related structures Vitaly Rodionov
2025-10-23 9:03 ` [PATCH v6 11/12] ASoC: dt-bindings: sound: cirrus: cs530x: Add SPI bus support Vitaly Rodionov
2025-10-27 8:47 ` Krzysztof Kozlowski
2025-10-23 9:03 ` [PATCH v6 12/12] ASoC: cs530x: Add SPI bus support for cs530x parts Vitaly Rodionov
2025-10-28 16:09 ` [PATCH v6 00/12] Add support for Cirrus Logic CS530x DAC and CODEC variants Mark Brown
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20251023090327.58275-8-vitalyr@opensource.cirrus.com \
--to=vitalyr@opensource.cirrus.com \
--cc=broonie@kernel.org \
--cc=conor+dt@kernel.org \
--cc=david.rhodes@cirrus.com \
--cc=devicetree@vger.kernel.org \
--cc=krzk+dt@kernel.org \
--cc=lgirdwood@gmail.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-sound@vger.kernel.org \
--cc=patches@opensource.cirrus.com \
--cc=perex@perex.cz \
--cc=rf@opensource.cirrus.com \
--cc=robh@kernel.org \
--cc=tiwai@suse.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox